@@ -1,22 +1,19 @@
 #
 # This file is part of Config-Model-Approx
 #
-# This software is Copyright (c) 2012 by Dominique Dumont.
+# This software is Copyright (c) 2015-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
+use strict;
+use warnings;
 
-$model_to_test = "Approx" ;
-$conf_file_name = 'approx.conf';
-$conf_dir = '/etc/approx' ;
-
-@tests = (
-    { 
+my @tests = (
+    {
         name => 'basic' ,
-        load_warnings => undef , # some weird warnings pop up in Perl smoke tests with perl 5.15.9
-        check => { 
+        check => {
             # 'AuthorizedKeysFile:0' => '/etc/ssh/userkeys/%u',
             # 'AuthorizedKeysFile:1' => '/var/lib/misc/userkeys2/%u',
         },
@@ -26,4 +23,9 @@ $conf_dir = '/etc/approx' ;
     },
 );
 
-1;
+return {
+    model_to_test => "Approx" ,
+    conf_file_name => 'approx.conf',
+    conf_dir => '/etc/approx',
+    tests => \@tests
+};
